Welcome to ClientVPS Mirrors

Help for package equatags
Type: Package
Title: Equations to 'XML'
Version: 0.2.2
Description: Provides function to transform latex math expressions into format 'HTML' or 'Office Open XML Math'. The 'XML' result can then be included in 'HTML', 'Microsoft Word' documents or 'Microsoft PowerPoint' presentations by using a 'Markdown' document or the R package 'officer'.
BugReports: https://github.com/ardata-fr/equatags/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (≥ 4.0.0)
Imports: xml2, xslt, katex
NeedsCompilation: no
Packaged: 2025-08-18 13:29:12 UTC; davidgohel
Author: David Gohel [aut, cre], ArData [cph]
Maintainer: David Gohel <david.gohel@ardata.fr>
Repository: CRAN
Date/Publication: 2025-08-18 14:40:02 UTC

'MathJax' equation as 'HTML' or 'MathML'.

Description

Get 'HTML' or 'MathML' XML codes corresponding to the rendering of 'MathJax' equations.

Usage

transform_mathjax(x, to = "html", display = FALSE, strict = "ignore")

Arguments

x

MathJax equations

to

output format, one of 'html' or 'mml'

display

should the equation be in display (TRUE) or inline mode (FALSE, by default)

strict

KaTeX option.If "ignore" (default), allow features that make writing LaTeX convenient. Other options are "warn" or "error". This happens E;G;, when you use accented characters in your equations.

Value

a character vector that contains 'html' or 'mml' codes corresponding to the equations.

Examples

x <- c("(ax^2 + bx + c = 0)",
       "x = {-b \\pm \\sqrt{b^2-4ac} \\over 2a}.")
z <- transform_mathjax(x = x, to = "html")
cat(z, sep = "\n\n")
z <- transform_mathjax(x = x, to = "mml")
cat(z, sep = "\n\n")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.